==> openshift-enterprise-console-container-v4.2.26-202003230335.tar.gz: openshift-enterprise-console-container-v4.2.26-202003230335/frontend/packages/kubevirt-plugin/integration-tests/tests/models/detailView.ts <==
import { browser } from 'protractor';
import { appHost, testName } from '../../../../../integration-tests/protractor.conf';
import { clickHorizontalTab } from '../../../../../integration-tests/views/horizontal-nav.view';
import { isLoaded, resourceTitle } from '../../../../../integration-tests/views/crud.view';
import { activeTab } from '../../views/detailView.view';

export class DetailView {
  readonly name: string;

  readonly namespace: string;

  readonly kind: string;

  constructor(instance) {
    this.name = instance.name;
    this.namespace = instance.namespace;
    this.kind = instance.kind;
  }

  static async getResourceTitle() {
    return resourceTitle.getText();
  }

  async navigateToTab(tabName: string) {
    if (!(await resourceTitle.isPresent()) || (await resourceTitle.getText()) !== this.name) {
      await browser.get(`${appHost}/k8s/ns/${this.namespace}/${this.kind}/${this.name}`);
      await isLoaded();
    }
    if ((await activeTab.getText()) !== tabName) {
      await clickHorizontalTab(tabName);
      await isLoaded();
    }
  }

  async navigateToListView() {
    const vmsListUrl = (namespace) =>
      `${appHost}/k8s/${namespace === 'all-namespaces' ? '' : 'ns/'}${namespace}/${this.kind}`;
    const currentUrl = await browser.getCurrentUrl();
    if (![vmsListUrl(testName), vmsListUrl('all-namespaces')].includes(currentUrl)) {
      await browser.get(vmsListUrl(this.namespace));
      await isLoaded();
    }
  }

  asResource() {
    return {
      kind: this.kind,
      metadata: {
        namespace: this.namespace,
        name: this.name,
      },
    };
  }
}

==> openshift-enterprise-console-container-v4.3.0-202001211731.tar.gz: openshift-enterprise-console-container-v4.3.0-202001211731/frontend/packages/kubevirt-plugin/integration-tests/tests/models/detailView.ts <==
import { browser } from 'protractor';
import { appHost, testName } from '@console/internal-integration-tests/protractor.conf';
import { clickHorizontalTab } from '@console/internal-integration-tests/views/horizontal-nav.view';
import { isLoaded, resourceTitle } from '@console/internal-integration-tests/views/crud.view';
import { activeTab } from '../../views/detailView.view';
import * as VmsListView from '../../views/vms.list.view';

export class DetailView {
  readonly name: string;

  readonly namespace: string;

  readonly kind: string;

  constructor(instance) {
    this.name = instance.name;
    this.namespace = instance.namespace;
    this.kind = instance.kind;
  }

  static async getResourceTitle() {
    return resourceTitle.getText();
  }

  async navigateToTab(tabName: string) {
    if (!(await resourceTitle.isPresent()) || (await resourceTitle.getText()) !== this.name) {
      await browser.get(`${appHost}/k8s/ns/${this.namespace}/${this.kind}/${this.name}`);
      await isLoaded();
    }
    if ((await activeTab.getText()) !== tabName) {
      await clickHorizontalTab(tabName);
      await isLoaded();
    }
  }

  // Similar to navigateToTab(TABS.OVERVIEW) but passes through resource list page
  async navigateToDetail() {
    await this.navigateToListView();
    await VmsListView.vmListByName(this.name).click();
    await isLoaded();
    await clickHorizontalTab('Overview');
    await isLoaded();
  }

  async navigateToListView() {
    const vmsListUrl = (namespace) =>
      `${appHost}/k8s/${namespace === 'all-namespaces' ? '' : 'ns/'}${namespace}/${this.kind}`;
    const currentUrl = await browser.getCurrentUrl();
    if (![vmsListUrl(testName), vmsListUrl('all-namespaces')].includes(currentUrl)) {
      await browser.get(vmsListUrl(this.namespace));
      await isLoaded();
    }
  }

  asResource() {
    return {
      kind: this.kind,
      metadata: {
        namespace: this.namespace,
        name: this.name,
      },
    };
  }
}
